All of lore.kernel.org
 help / color / mirror / Atom feed
* [to-be-updated] vmalloc-use-apply_to_page_range_batch-in-alloc_vm_area.patch removed from -mm tree
@ 2011-05-18 21:37 akpm
  0 siblings, 0 replies; only message in thread
From: akpm @ 2011-05-18 21:37 UTC (permalink / raw)
  To: jeremy.fitzhardinge, hugh.dickins, npiggin, mm-commits


The patch titled
     vmalloc: use apply_to_page_range_batch() in alloc_vm_area()
has been removed from the -mm tree.  Its filename was
     vmalloc-use-apply_to_page_range_batch-in-alloc_vm_area.patch

This patch was dropped because an updated version will be merged

The current -mm tree may be found at http://userweb.kernel.org/~akpm/mmotm/

------------------------------------------------------
Subject: vmalloc: use apply_to_page_range_batch() in alloc_vm_area()
From: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>

Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
Cc: Nick Piggin <npiggin@kernel.dk>
Cc: Hugh Dickins <hugh.dickins@tiscali.co.uk>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---

 mm/vmalloc.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff -puN mm/vmalloc.c~vmalloc-use-apply_to_page_range_batch-in-alloc_vm_area mm/vmalloc.c
--- a/mm/vmalloc.c~vmalloc-use-apply_to_page_range_batch-in-alloc_vm_area
+++ a/mm/vmalloc.c
@@ -2048,9 +2048,9 @@ void  __attribute__((weak)) vmalloc_sync
 }
 
 
-static int f(pte_t *pte, unsigned long addr, void *data)
+static int f(pte_t *pte, unsigned count, unsigned long addr, void *data)
 {
 	/* apply_to_page_range() does all the hard work. */
 	return 0;
 }
 
@@ -2079,8 +2079,8 @@ struct vm_struct *alloc_vm_area(size_t s
 	 * This ensures that page tables are constructed for this region
 	 * of kernel virtual address space and mapped into init_mm.
 	 */
-	if (apply_to_page_range(&init_mm, (unsigned long)area->addr,
-				area->size, f, NULL)) {
+	if (apply_to_page_range_batch(&init_mm, (unsigned long)area->addr,
+				      area->size, f, NULL)) {
 		free_vm_area(area);
 		return NULL;
 	}
_

Patches currently in -mm which might be from jeremy.fitzhardinge@citrix.com are

linux-next.patch
xen-mmu-use-apply_to_page_range_batch-in-xen_remap_domain_mfn_range.patch
xen-grant-table-use-apply_to_page_range_batch.patch


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2011-05-18 21:37 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -2048,9 +2048,9 @@ void  __attribute__((weak)) vmalloc_sync
 {
-	/* apply_to_page_range() does all the hard work. */
+	/* apply_to_page_range_batch() does all the hard work. */
 	return 0;
 }
2011-05-18 21:37 [to-be-updated] vmalloc-use-apply_to_page_range_batch-in-alloc_vm_area.patch removed from -mm tree akpm

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.